﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Net.Http;
using System.Threading.Tasks;

namespace ConsoleApp1
{
    class AzureRestClient
    {
        HttpClient _client;
        string _subscriptionId;
        string _apiVersion = "2017-12-01";

        public AzureRestClient()
        {
            _client = new HttpClient();
        }

        public async Task<bool> Login(string authData)
        {
            AuthInfo authInfo = JsonConvert.DeserializeObject<AuthInfo>(authData);
            if (authInfo == null)
            {
                return false;
            }

            string oauth2AzureAD = string.Format("https://login.microsoftonline.com/{0}/oauth2/token", authInfo.tenantId);

            var dict = new Dictionary<string, string>();
            dict.Add("grant_type", "client_credentials");
            dict.Add("client_id", authInfo.clientId);
            dict.Add("client_secret", authInfo.clientSecret);
            dict.Add("resource", authInfo.resourceManagerEndpointUrl);
            var client = new HttpClient();
            var req = new HttpRequestMessage(HttpMethod.Post, oauth2AzureAD) { Content = new FormUrlEncodedContent(dict) };
            HttpResponseMessage hrm = await client.SendAsync(req);

            string result = await hrm.Content.ReadAsStringAsync();

            TokenInfo tokenInfo = JsonConvert.DeserializeObject<TokenInfo>(result);
            string tokenType = tokenInfo.token_type;
            string accessToken = tokenInfo.access_token;

            string authHeader = string.Format("{0} {1}", tokenType, accessToken);
            _client.DefaultRequestHeaders.Add("Authorization", authHeader);
            _subscriptionId = authInfo.subscriptionId;

            return true;
        }

        public async Task<VirtualMachineList> GetVMList()
        {
            string url = string.Format(
                "https://management.azure.com/subscriptions/{0}/providers/Microsoft.Compute/virtualMachines?api-version={1}", _subscriptionId, _apiVersion);

            HttpResponseMessage hrm = await _client.GetAsync(url);
            string result = await hrm.Content.ReadAsStringAsync();

            VirtualMachineList list = JsonConvert.DeserializeObject<VirtualMachineList>(result);
            return list;
        }
    }
}
